<?php

namespace Beo\Career\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;

use Beo\Career\Interfaces\ProfileRepositoryInterface;
use Beo\Career\Repositories\Eloquent\Filters\ProfilePublicFilter;
use Beo\Career\Repositories\Eloquent\Presenters\ProfileListPresenter;

class ProfilePublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(
        ProfileRepositoryInterface $profile
    ) {
        parent::__construct();
        $this->modules = $this->modules(config('beo.career.modules'), 'profile', guard_url('profile'));
        $this->repository = $profile;
    }

    /**
     * Show profile's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(ProfilePublicFilter::class)
            ->setPresenter(ProfileListPresenter::class)
            ->select('profiles.*')
            ->paginate($pageLimit)
            ->withQueryString()
            ->toArray();

        extract($data);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('career::profile.names'))
            ->view('career::public.profile.index')
            ->data(compact('data', 'meta', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show profile.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('career::profile.name'))
            ->view('career::public.profile.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
