<?php

namespace Beo\Career\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Beo\Career\Http\Requests\ProfileRequest;
use Beo\Career\Models\Profile;

/**
 * Admin web controller class.
 */
class ProfileWorkflowController extends BaseController
{

    /**
     * Workflow controller function for profile.
     *
     * @param Model   $profile
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(ProfileRequest $request, Profile $profile, $step)
    {

        try {

            $profile->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('career::profile.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/profile/profile/' . $profile->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/profile/profile/' . $profile->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for profile.
     *
     * @param Model   $profile
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Profile $profile, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $profile->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('career::profile.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('career::admin.profile.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('career::admin.profile.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('career::admin.profile.message', $data)->render();

        }

    }
}
