<?php

namespace Beo\Career\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Beo\Career\Models\Job;

class JobPolicy
{

    /**
     * Determine if the given user can view the job.
     *
     * @param UserPolicyInterface $authUser
     * @param Job $job
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Job $job)
    {
        if ($authUser->canDo('career.job.view') && $authUser->isAdmin()) {
            return true;
        }

        return $job->user_id == user_id() && $job->user_type == user_type();
    }

    /**
     * Determine if the given user can create a job.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('career.job.create');
    }

    /**
     * Determine if the given user can update the given job.
     *
     * @param UserPolicyInterface $authUser
     * @param Job $job
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Job $job)
    {
        if ($authUser->canDo('career.job.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $job->user_id == user_id() && $job->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given job.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Job $job)
    {
        return $job->user_id == user_id() && $job->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given job.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Job $job)
    {
        if ($authUser->canDo('career.job.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given job.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Job $job)
    {
        if ($authUser->canDo('career.job.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
