<?php

namespace Beo\Career\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Beo\Career\Models\Job;

class JobAction
{
    /**
     * Perform the complete action.
     *
     * @param Job $job
     *
     * @return Job
     */
    public function complete(Job $job)
    {
        try {
            $job->status = 'complete';
            return $job->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Job $job
     *
     * @return Job
     */public function verify(Job $job)
    {
        try {
            $job->status = 'verify';
            return $job->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Job $job
     *
     * @return Job
     */public function approve(Job $job)
    {
        try {
            $job->status = 'approve';
            return $job->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Job $job
     *
     * @return Job
     */public function publish(Job $job)
    {
        try {
            $job->status = 'publish';
            return $job->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Job $job
     *
     * @return Job
     */
    public function archive(Job $job)
    {
        try {
            $job->status = 'archive';
            return $job->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Job $job
     *
     * @return Job
     */
    public function unpublish(Job $job)
    {
        try {
            $job->status = 'unpublish';
            return $job->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
