<?php

namespace Beo\Career\Workflow;

use Beo\Career\Models\Job;
use Validator;

class JobValidator
{

    /**
     * Determine if the given job is valid for complete status.
     *
     * @param Job $job
     *
     * @return bool / Validator
     */
    public function complete(Job $job)
    {
        return Validator::make($job->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given job is valid for verify status.
     *
     * @param Job $job
     *
     * @return bool / Validator
     */
    public function verify(Job $job)
    {
        return Validator::make($job->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given job is valid for approve status.
     *
     * @param Job $job
     *
     * @return bool / Validator
     */
    public function approve(Job $job)
    {
        return Validator::make($job->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given job is valid for publish status.
     *
     * @param Job $job
     *
     * @return bool / Validator
     */
    public function publish(Job $job)
    {
        return Validator::make($job->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given job is valid for archive status.
     *
     * @param Job $job
     *
     * @return bool / Validator
     */
    public function archive(Job $job)
    {
        return Validator::make($job->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given job is valid for unpublish status.
     *
     * @param Job $job
     *
     * @return bool / Validator
     */
    public function unpublish(Job $job)
    {
        return Validator::make($job->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
