<?php

namespace Beo\Career\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Beo\Career\Models\Profile;

class ProfileAction
{
    /**
     * Perform the complete action.
     *
     * @param Profile $profile
     *
     * @return Profile
     */
    public function complete(Profile $profile)
    {
        try {
            $profile->status = 'complete';
            return $profile->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Profile $profile
     *
     * @return Profile
     */public function verify(Profile $profile)
    {
        try {
            $profile->status = 'verify';
            return $profile->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Profile $profile
     *
     * @return Profile
     */public function approve(Profile $profile)
    {
        try {
            $profile->status = 'approve';
            return $profile->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Profile $profile
     *
     * @return Profile
     */public function publish(Profile $profile)
    {
        try {
            $profile->status = 'publish';
            return $profile->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Profile $profile
     *
     * @return Profile
     */
    public function archive(Profile $profile)
    {
        try {
            $profile->status = 'archive';
            return $profile->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Profile $profile
     *
     * @return Profile
     */
    public function unpublish(Profile $profile)
    {
        try {
            $profile->status = 'unpublish';
            return $profile->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
