<?php

namespace Beo\Career\Workflow;

use Beo\Career\Models\Profile;
use Validator;

class ProfileValidator
{

    /**
     * Determine if the given profile is valid for complete status.
     *
     * @param Profile $profile
     *
     * @return bool / Validator
     */
    public function complete(Profile $profile)
    {
        return Validator::make($profile->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given profile is valid for verify status.
     *
     * @param Profile $profile
     *
     * @return bool / Validator
     */
    public function verify(Profile $profile)
    {
        return Validator::make($profile->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given profile is valid for approve status.
     *
     * @param Profile $profile
     *
     * @return bool / Validator
     */
    public function approve(Profile $profile)
    {
        return Validator::make($profile->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given profile is valid for publish status.
     *
     * @param Profile $profile
     *
     * @return bool / Validator
     */
    public function publish(Profile $profile)
    {
        return Validator::make($profile->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given profile is valid for archive status.
     *
     * @param Profile $profile
     *
     * @return bool / Validator
     */
    public function archive(Profile $profile)
    {
        return Validator::make($profile->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given profile is valid for unpublish status.
     *
     * @param Profile $profile
     *
     * @return bool / Validator
     */
    public function unpublish(Profile $profile)
    {
        return Validator::make($profile->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
